==> language-ga-5.9-sources.jar: org/languagetool/rules/ga/PrestandardReplaceRule.java <==
/* LanguageTool, a natural language style checker
 * Copyright (C) 2005 Daniel Naber (http://www.danielnaber.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */
package org.languagetool.rules.ga;

import org.languagetool.rules.AbstractSimpleReplaceRule;
import org.languagetool.rules.Categories;
import org.languagetool.rules.Example;
import org.languagetool.rules.ITSIssueType;

import java.io.IOException;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * A rule that matches words which should not be used and suggests
 * correct ones instead.
 *
 * Irish version for pre-standard spellings
 * relevant words from <code>rules/ga/replace-prestandard.txt</code>.
 *
 * @author Jim O'Regan
 */
public class PrestandardReplaceRule extends AbstractSimpleReplaceRule {

  private static final Map<String, List<String>> wrongWords = loadFromPath("/ga/replace-prestandard.txt");
  private static final Locale GA_LOCALE = new Locale("GA");

  @Override
  protected Map<String, List<String>> getWrongWords() {
    return wrongWords;
  }

  public PrestandardReplaceRule(final ResourceBundle messages) throws IOException {
    super(messages);
    super.setCategory(Categories.TYPOS.getCategory(messages));
    super.setLocQualityIssueType(ITSIssueType.Misspelling);
    addExamplePair(Example.wrong("“Ní <marker>baoghal</marker> daoibh,” ar sise."),
                   Example.fixed("“Ní <marker>baol</marker> daoibh,” ar sise."));
    this.setCheckLemmas(false);
  }

  @Override
  public final String getId() {
    return "GA_PRESTANDARD_REPLACE";
  }

  @Override
  public String getDescription() {
    return "Litriú réamhchaighdeánach, m.sh., \"baoghal\" in áit \"baol\"";
  }

  @Override
  public String getShort() {
    return "Litriú réamhchaighdeánach";
  }

  @Override
  public String getMessage(String tokenStr,List<String> replacements) {
    return "Litriú réamhchaighdeánach:\""
        + String.join(", ", replacements) + "\".";
  }

  @Override
  public boolean isCaseSensitive() {
    return false;
  }

  @Override
  public Locale getLocale() {
    return GA_LOCALE;
  }

}

==> language-ga-6.4-sources.jar: org/languagetool/rules/ga/PrestandardReplaceRule.java <==
/* LanguageTool, a natural language style checker
 * Copyright (C) 2005 Daniel Naber (http://www.danielnaber.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */
package org.languagetool.rules.ga;

import org.languagetool.Language;
import org.languagetool.rules.AbstractSimpleReplaceRule;
import org.languagetool.rules.Categories;
import org.languagetool.rules.Example;
import org.languagetool.rules.ITSIssueType;

import java.io.IOException;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * A rule that matches words which should not be used and suggests
 * correct ones instead.
 *
 * Irish version for pre-standard spellings
 * relevant words from <code>rules/ga/replace-prestandard.txt</code>.
 *
 * @author Jim O'Regan
 */
public class PrestandardReplaceRule extends AbstractSimpleReplaceRule {

  private static final Map<String, List<String>> wrongWords = loadFromPath("/ga/replace-prestandard.txt");
  private static final Locale GA_LOCALE = new Locale("GA");

  @Override
  public Map<String, List<String>> getWrongWords() {
    return wrongWords;
  }

  public PrestandardReplaceRule(ResourceBundle messages, Language language) throws IOException {
    super(messages, language);
    super.setCategory(Categories.TYPOS.getCategory(messages));
    super.setLocQualityIssueType(ITSIssueType.Misspelling);
    addExamplePair(Example.wrong("“Ní <marker>baoghal</marker> daoibh,” ar sise."),
                   Example.fixed("“Ní <marker>baol</marker> daoibh,” ar sise."));
    this.setCheckLemmas(false);
  }

  @Override
  public final String getId() {
    return "GA_PRESTANDARD_REPLACE";
  }

  @Override
  public String getDescription() {
    return "Litriú réamhchaighdeánach, m.sh., \"baoghal\" in áit \"baol\"";
  }

  @Override
  public String getShort() {
    return "Litriú réamhchaighdeánach";
  }

  @Override
  public String getMessage(String tokenStr,List<String> replacements) {
    return "Litriú réamhchaighdeánach:\""
        + String.join(", ", replacements) + "\".";
  }

  @Override
  public boolean isCaseSensitive() {
    return false;
  }

  @Override
  public Locale getLocale() {
    return GA_LOCALE;
  }

}
